import json, requests, urllib3

# fix cert warnigns

urllib3.disable_warnings(urllib3.exceptions.InsecureRequestWarning)

# login function

def ledlogin (user, password, ip, port):

    headers = {
        'Content-Type': 'application/json',
        'Accept': '*/*',
    }

    data = '{"username":"' + user + '","password":"' + password + '"}'

    try:

        response = requests.post('https://' + ip + ':' + port + '/v1/login', headers=headers, data=data, verify=False)

    except requests.exceptions.RequestException as e:  # This is the correct syntax

        return None

    output = json.loads(response.content)

    if response.status_code == 200:

        return output

    elif response.status_code == 403:

        return False

    else:

        return None



import json, requests, urllib3

# fix cert warnigns

urllib3.disable_warnings(urllib3.exceptions.InsecureRequestWarning)

# set device brightness

def leddevicesetbrightness (deviceid, brightness,session, ip, port):

    headers = {
        'Authorization': 'Bearer ' + session['access_token'],
        'Content-Type': 'application/json',
        'Accept': '*/*',
    }

    data = '{"command":"sync","value":' + str(brightness) + '}'

    response = requests.put('https://' + ip + ':' + port + '/v1/devices/' + deviceid , headers=headers, data=data, verify=False)

    if response.status_code == 200:

        return True

    else:

        return False

# set device output

def leddevicesetoutput (deviceid, output,session, ip, port):

    headers = {
        'Authorization': 'Bearer ' + session['access_token'],
        'Content-Type': 'application/json',
        'Accept': '*/*',
    }

    data = '{"command":"config-output","value":' + str(output) + '}'

    response = requests.put('https://' + ip + ':' + port + '/v1/devices/' + deviceid , headers=headers, data=data, verify=False)

    if response.status_code == 200:

        return True

    else:

        return False



import json, requests, urllib3

# fix cert warnigns

urllib3.disable_warnings(urllib3.exceptions.InsecureRequestWarning)

# get devices function

def leddevices (session, ip, port):

    headers = {
        'Content-Type': 'application/json',
        'Accept': '*/*',
        'Authorization': 'Bearer ' + session['access_token'],
    }

    response = requests.get('https://192.168.255.41:20443/v1/devices', headers=headers, verify=False)

    output = json.loads(response.content)

    if response.status_code == 200:

        return output

    else:

        return False

# get groups function

def ledgroups (session, ip, port):

    headers = {
        'Content-Type': 'application/json',
        'Accept': '*/*',
        'Authorization': 'Bearer ' + session['access_token'],
    }

    response = requests.get('https://192.168.255.41:20443/v1/groups', headers=headers, verify=False)

    output = json.loads(response.content)

    if response.status_code == 200:

        return output

    else:

        return False
